@@ -963,7 +963,7 @@ redo_dump:
         ((SvFLAGS(src) & (SVs_OBJECT|SVf_OK|SVs_GMG|SVs_SMG|SVs_RMG)) == (SVs_OBJECT|BFD_Svs_SMG_OR_RMG)) &&
         (mg = mg_find(src, PERL_MAGIC_qr))
     ) {
-            /* Housten, we have a regex! */
+            /* Houston, we have a regex! */
         srl_dump_regexp(aTHX_ enc, (SV*)mg); /* yes the SV* cast makes me feel dirty too */
     }
     else
@@ -987,8 +987,13 @@ redo_dump:
                         warn("Found type %u %s(0x%p), but it is not representable "            \
                              "by the Sereal encoding format; will encode as an "               \
                              "undefined value", (svt), sv_reftype((src),0),(src));             \
-                    if (ref_rewrite_pos)                                                       \
+                    if (ref_rewrite_pos) {                                                     \
+                        /* make sure we don't keep a reference to the thing that we do not     \
+                         * want to serialize around for REFP and ALIAS output */               \
+                        PTABLE_t *ref_seenhash= SRL_GET_REF_SEENHASH(enc);                     \
+                        PTABLE_delete(ref_seenhash, src);                                      \
                         enc->pos= enc->buf_start + ref_rewrite_pos;                            \
+                    }                                                                          \
                     srl_buf_cat_char((enc), SRL_HDR_UNDEF);                                    \
                 }                                                                              \
                 else if ( SRL_ENC_HAVE_OPTION((enc), SRL_F_STRINGIFY_UNKNOWN) ) {              \
@@ -1010,7 +1015,11 @@ redo_dump:
                                  "stringified form", (svt), sv_reftype((src),0),(src));        \
                         }                                                                      \
                     }                                                                          \
-                    if (refsv) {                                                               \
+                    if (ref_rewrite_pos) {                                                     \
+                        /* make sure we don't keep a reference to the thing that we do not     \
+                         * want to serialize around for REFP and ALIAS output */               \
+                        PTABLE_t *ref_seenhash= SRL_GET_REF_SEENHASH(enc);                     \
+                        PTABLE_delete(ref_seenhash, src);                                      \
                         enc->pos= enc->buf_start + ref_rewrite_pos;                            \
                         str = SvPV((refsv), len);                                              \
                     } else                                                                     \
